@@ -7,7 +7,7 @@ from .path import *
 
 # Change neuropsydia.screen to "__main__" When building API documentation. This is to avoid sphinx to run this code, otherwise the documentations fails to be built. "neuropsydia.screen" to make it work.
 
-if __name__ == "neuropsydia.screen":
+if __name__ == "myNeuropsydia.screen":
     # Add icon to the window
     pygame.display.set_icon(pygame.image.load(Path.logo() + 'icon.png'))
 
